@@ -6,10 +6,12 @@
     Support for domains, which are groupings of description directives
     and roles describing e.g. constructs of one programming language.
 
-    :copyright: Copyright 2007-2011 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+from six import iteritems
+
 from sphinx.errors import SphinxError
 from sphinx.locale import _
 
@@ -66,9 +68,8 @@ class Index(object):
         self.domain = domain
 
     def generate(self, docnames=None):
-        """
-        Return entries for the index given by *name*.  If *docnames* is given,
-        restrict to entries referring to these docnames.
+        """Return entries for the index given by *name*.  If *docnames* is
+        given, restrict to entries referring to these docnames.
 
         The return value is a tuple of ``(content, collapse)``, where *collapse*
         is a boolean that determines if sub-entries should start collapsed (for
@@ -132,6 +133,8 @@ class Domain(object):
     roles = {}
     #: a list of Index subclasses
     indices = []
+    #: role name -> a warning message if reference is missing
+    dangling_warnings = {}
 
     #: data value for a fresh environment
     initial_data = {}
@@ -152,14 +155,16 @@ class Domain(object):
         self._role_cache = {}
         self._directive_cache = {}
         self._role2type = {}
-        for name, obj in self.object_types.iteritems():
+        self._type2role = {}
+        for name, obj in iteritems(self.object_types):
             for rolename in obj.roles:
                 self._role2type.setdefault(rolename, []).append(name)
+            self._type2role[name] = obj.roles[0] if obj.roles else ''
         self.objtypes_for_role = self._role2type.get
+        self.role_for_objtype = self._type2role.get
 
     def role(self, name):
-        """
-        Return a role adapter function that always gives the registered
+        """Return a role adapter function that always gives the registered
         role its full name ('domain:name') as the first argument.
         """
         if name in self._role_cache:
@@ -167,6 +172,7 @@ class Domain(object):
         if name not in self.roles:
             return None
         fullname = '%s:%s' % (self.name, name)
+
         def role_adapter(typ, rawtext, text, lineno, inliner,
                          options={}, content=[]):
             return self.roles[name](fullname, rawtext, text, lineno,
@@ -175,8 +181,7 @@ class Domain(object):
         return role_adapter
 
     def directive(self, name):
-        """
-        Return a directive adapter class that always gives the registered
+        """Return a directive adapter class that always gives the registered
         directive its full name ('domain:name') as ``self.name``.
         """
         if name in self._directive_cache:
@@ -185,6 +190,7 @@ class Domain(object):
             return None
         fullname = '%s:%s' % (self.name, name)
         BaseDirective = self.directives[name]
+
         class DirectiveAdapter(BaseDirective):
             def run(self):
                 self.name = fullname
@@ -195,21 +201,24 @@ class Domain(object):
     # methods that should be overwritten
 
     def clear_doc(self, docname):
-        """
-        Remove traces of a document in the domain-specific inventories.
-        """
+        """Remove traces of a document in the domain-specific inventories."""
         pass
 
+    def merge_domaindata(self, docnames, otherdata):
+        """Merge in data regarding *docnames* from a different domaindata
+        inventory (coming from a subprocess in parallel builds).
+        """
+        raise NotImplementedError('merge_domaindata must be implemented in %s '
+                                  'to be able to do parallel builds!' %
+                                  self.__class__)
+
     def process_doc(self, env, docname, document):
-        """
-        Process a document after it is read by the environment.
-        """
+        """Process a document after it is read by the environment."""
         pass
 
     def resolve_xref(self, env, fromdocname, builder,
                      typ, target, node, contnode):
-        """
-        Resolve the ``pending_xref`` *node* with the given *typ* and *target*.
+        """Resolve the pending_xref *node* with the given *typ* and *target*.
 
         This method should return a new node, to replace the xref node,
         containing the *contnode* which is the markup content of the
@@ -224,9 +233,24 @@ class Domain(object):
         """
         pass
 
-    def get_objects(self):
+    def resolve_any_xref(self, env, fromdocname, builder, target, node, contnode):
+        """Resolve the pending_xref *node* with the given *target*.
+
+        The reference comes from an "any" or similar role, which means that we
+        don't know the type.  Otherwise, the arguments are the same as for
+        :meth:`resolve_xref`.
+
+        The method must return a list (potentially empty) of tuples
+        ``('domain:role', newnode)``, where ``'domain:role'`` is the name of a
+        role that could have created the same reference, e.g. ``'py:func'``.
+        ``newnode`` is what :meth:`resolve_xref` would return.
+
+        .. versionadded:: 1.3
         """
-        Return an iterable of "object descriptions", which are tuples with
+        raise NotImplementedError
+
+    def get_objects(self):
+        """Return an iterable of "object descriptions", which are tuples with
         five items:
 
         * `name`     -- fully qualified name
@@ -245,20 +269,18 @@ class Domain(object):
         return []
 
     def get_type_name(self, type, primary=False):
-        """
-        Return full name for given ObjType.
-        """
+        """Return full name for given ObjType."""
         if primary:
             return type.lname
         return _('%s %s') % (self.label, type.lname)
 
 
-from sphinx.domains.c import CDomain
-from sphinx.domains.cpp import CPPDomain
-from sphinx.domains.std import StandardDomain
-from sphinx.domains.python import PythonDomain
-from sphinx.domains.javascript import JavaScriptDomain
-from sphinx.domains.rst import ReSTDomain
+from sphinx.domains.c import CDomain                     # noqa
+from sphinx.domains.cpp import CPPDomain                 # noqa
+from sphinx.domains.std import StandardDomain            # noqa
+from sphinx.domains.python import PythonDomain           # noqa
+from sphinx.domains.javascript import JavaScriptDomain   # noqa
+from sphinx.domains.rst import ReSTDomain                # noqa
 
 BUILTIN_DOMAINS = {
     'std': StandardDomain,
