@@ -5,7 +5,7 @@
 
     Test various Sphinx-specific markup extensions.
 
-    :copyright: Copyright 2007-2013 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -15,7 +15,6 @@ from docutils import frontend, utils, nodes
 from docutils.parsers import rst
 
 from sphinx.util import texescape
-from sphinx.util.pycompat import b
 from sphinx.writers.html import HTMLWriter, SmartyPantsHTMLTranslator
 from sphinx.writers.latex import LaTeXWriter, LaTeXTranslator
 
@@ -24,10 +23,11 @@ from util import TestApp
 
 app = settings = parser = None
 
+
 def setup_module():
     global app, settings, parser
     texescape.init()  # otherwise done by the latex builder
-    app = TestApp(cleanenv=True)
+    app = TestApp()
     optparser = frontend.OptionParser(
         components=(rst.Parser, HTMLWriter, LaTeXWriter))
     settings = optparser.get_default_values()
@@ -36,6 +36,7 @@ def setup_module():
     settings.env.temp_data['docname'] = 'dummy'
     parser = rst.Parser()
 
+
 def teardown_module():
     app.cleanup()
 
@@ -43,18 +44,21 @@ def teardown_module():
 class ForgivingTranslator:
     def visit_pending_xref(self, node):
         pass
+
     def depart_pending_xref(self, node):
         pass
 
+
 class ForgivingHTMLTranslator(SmartyPantsHTMLTranslator, ForgivingTranslator):
     pass
 
+
 class ForgivingLaTeXTranslator(LaTeXTranslator, ForgivingTranslator):
     pass
 
 
 def verify_re(rst, html_expected, latex_expected):
-    document = utils.new_document(b('test data'), settings)
+    document = utils.new_document(b'test data', settings)
     document['file'] = 'dummy'
     parser.parse(rst, document)
     for msg in document.traverse(nodes.system_message):
@@ -84,40 +88,41 @@ def verify(rst, html_expected, latex_expected):
 
 def test_inline():
     # correct interpretation of code with whitespace
-    _html = ('<p><tt class="(samp )?docutils literal"><span class="pre">'
-             'code</span>&nbsp;&nbsp; <span class="pre">sample</span></tt></p>')
+    _html = ('<p><code class="(samp )?docutils literal"><span class="pre">'
+             'code</span>&nbsp;&nbsp; <span class="pre">sample</span></code></p>')
     yield verify_re, '``code   sample``', _html, r'\\code{code   sample}'
     yield verify_re, ':samp:`code   sample`', _html, r'\\code{code   sample}'
 
     # interpolation of braces in samp and file roles (HTML only)
     yield (verify, ':samp:`a{b}c`',
-           '<p><tt class="samp docutils literal"><span class="pre">a</span>'
+           '<p><code class="samp docutils literal"><span class="pre">a</span>'
            '<em><span class="pre">b</span></em>'
-           '<span class="pre">c</span></tt></p>',
+           '<span class="pre">c</span></code></p>',
            '\\code{a\\emph{b}c}')
 
     # interpolation of arrows in menuselection
     yield (verify, ':menuselection:`a --> b`',
-           u'<p><em class="menuselection">a \N{TRIANGULAR BULLET} b</em></p>',
+           u'<p><span class="menuselection">a \N{TRIANGULAR BULLET} b</span></p>',
            '\\emph{a \\(\\rightarrow\\) b}')
 
     # interpolation of ampersands in guilabel/menuselection
     yield (verify, ':guilabel:`&Foo -&&- &Bar`',
-           u'<p><em class="guilabel"><span class="accelerator">F</span>oo '
-           '-&amp;- <span class="accelerator">B</span>ar</em></p>',
+           u'<p><span class="guilabel"><span class="accelerator">F</span>oo '
+           '-&amp;- <span class="accelerator">B</span>ar</span></p>',
            r'\emph{\DUspan{accelerator}{F}oo -\&- \DUspan{accelerator}{B}ar}')
 
     # non-interpolation of dashes in option role
     yield (verify_re, ':option:`--with-option`',
-           '<p><em( class="xref std std-option")?>--with-option</em></p>$',
-           r'\\emph{\\texttt{-{-}with-option}}$')
+           '<p><code( class="xref std std-option docutils literal")?>'
+           '<span class="pre">--with-option</span></code></p>$',
+           r'\\code{-{-}with-option}$')
 
     # verify smarty-pants quotes
     yield verify, '"John"', '<p>&#8220;John&#8221;</p>', "``John''"
     # ... but not in literal text
     yield (verify, '``"John"``',
-           '<p><tt class="docutils literal"><span class="pre">'
-           '&quot;John&quot;</span></tt></p>',
+           '<p><code class="docutils literal"><span class="pre">'
+           '&quot;John&quot;</span></code></p>',
            '\\code{"John"}')
 
     # verify classes for inline roles
@@ -128,7 +133,7 @@ def test_inline():
 def test_latex_escaping():
     # correct escaping in normal mode
     yield (verify, u'Γ\\\\∞$', None,
-           ur'\(\Gamma\)\textbackslash{}\(\infty\)\$')
+           r'\(\Gamma\)\textbackslash{}\(\infty\)\$')
     # in verbatim code fragments
     yield (verify, u'::\n\n @Γ\\∞${}', None,
            u'\\begin{Verbatim}[commandchars=\\\\\\{\\}]\n'
@@ -136,4 +141,4 @@ def test_latex_escaping():
            u'\\end{Verbatim}')
     # in URIs
     yield (verify_re, u'`test <http://example.com/~me/>`_', None,
-           ur'\\href{http://example.com/~me/}{test}.*')
+           r'\\href{http://example.com/~me/}{test}.*')
