@@ -72,13 +72,13 @@ def test_get_catalogs_for_xx(dir):
     (dir / 'loc1' / 'xx' / 'LC_ALL').makedirs()
     (dir / 'loc1' / 'xx' / 'LC_ALL' / 'test7.po').write_text('#')
 
-    catalogs = i18n.get_catalogs([dir / 'loc1'], 'xx', force_all=False)
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', force_all=False)
     domains = set(c.domain for c in catalogs)
     assert domains == set([
         'test1',
         'test2',
-        path.normpath('sub/test4'),
-        path.normpath('sub/test5'),
+        'sub/test4',
+        'sub/test5',
     ])
 
 
@@ -89,22 +89,22 @@ def test_get_catalogs_for_en(dir):
     (dir / 'loc1' / 'en' / 'LC_MESSAGES').makedirs()
     (dir / 'loc1' / 'en' / 'LC_MESSAGES' / 'en_dom.po').write_text('#')
 
-    catalogs = i18n.get_catalogs([dir / 'loc1'], 'en', force_all=False)
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'en', force_all=False)
     domains = set(c.domain for c in catalogs)
     assert domains == set(['en_dom'])
 
 
 @with_tempdir
 def test_get_catalogs_with_non_existent_locale(dir):
-    catalogs = i18n.get_catalogs([dir / 'loc1'], 'xx')
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx')
     assert not catalogs
 
-    catalogs = i18n.get_catalogs([dir / 'loc1'], None)
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], None)
     assert not catalogs
 
 
 def test_get_catalogs_with_non_existent_locale_dirs():
-    catalogs = i18n.get_catalogs(['dummy'], 'xx')
+    catalogs = i18n.find_catalog_source_files(['dummy'], 'xx')
     assert not catalogs
 
 
@@ -123,16 +123,16 @@ def test_get_catalogs_for_xx_without_outdated(dir):
     (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.po').write_text('#')
     (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.mo').write_text('#')
 
-    catalogs = i18n.get_catalogs([dir / 'loc1'], 'xx', force_all=False)
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', force_all=False)
     assert not catalogs
 
-    catalogs = i18n.get_catalogs([dir / 'loc1'], 'xx', force_all=True)
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', force_all=True)
     domains = set(c.domain for c in catalogs)
     assert domains == set([
         'test1',
         'test2',
-        path.normpath('sub/test4'),
-        path.normpath('sub/test5'),
+        'sub/test4',
+        'sub/test5',
     ])
 
 
@@ -144,7 +144,7 @@ def test_get_catalogs_from_multiple_locale_dirs(dir):
     (dir / 'loc2' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
     (dir / 'loc2' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
 
-    catalogs = i18n.get_catalogs([dir / 'loc1', dir / 'loc2'], 'xx')
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1', dir / 'loc2'], 'xx')
     domains = sorted(c.domain for c in catalogs)
     assert domains == ['test1', 'test1', 'test2']
 
@@ -158,6 +158,6 @@ def test_get_catalogs_with_compact(dir):
     (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test3.po').write_text('#')
     (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
 
-    catalogs = i18n.get_catalogs([dir / 'loc1'], 'xx', gettext_compact=True)
+    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', gettext_compact=True)
     domains = set(c.domain for c in catalogs)
     assert domains == set(['test1', 'test2', 'sub'])
